/*
 * Screen Saver - Lockup Desktop replacement for OS/2 and eComStation systems
 * Copyright (C) 2004 Doodle
 *
 * Contact: doodle@dont.spam.me.scenergy.dfmk.hu
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 */

#ifndef __SSCORE_H__
#define __SSCORE_H__

#include "SSModule.h"

#define SSCORECALL __syscall
#define SSCOREDECLSPEC __declspec(dllexport)

// ----------------- Type and error definitions -----------------------

#define SSCORE_MAXPASSWORDLEN   128

typedef struct SSCoreVersionInfo_s
{
  int iVersionMajor;
  int iVersionMinor;

} SSCoreVersionInfo_t, *SSCoreVersionInfo_p;

typedef struct SSCoreModuleList_s
{
  SSModuleDesc_t  ModuleDesc;
  char            achModuleFileName[CCHMAXPATHCOMP];

  void *pNext;
} SSCoreModuleList_t, *SSCoreModuleList_p;

typedef struct SSCoreSettings_s
{
  int             bEnabled;         // Is saving enabled?

  int             iActivationTime;  // In msecs
  char            achModuleFileName[CCHMAXPATHCOMP]; // DLL filename to use

  int             bPasswordProtected; // Is saving password protected?
  char            achEncryptedPassword[SSCORE_MAXPASSWORDLEN]; // The encrypted password

} SSCoreSettings_t, *SSCoreSettings_p;


#define SSCORE_NOERROR                     0
#define SSCORE_ERROR_INVALIDPARAMETER      1
#define SSCORE_ERROR_NOTINITIALIZED        2
#define SSCORE_ERROR_NOTDISABLED           3
#define SSCORE_ERROR_ALREADYINITIALIZED    4
#define SSCORE_ERROR_ACCESSDENIED          5
#define SSCORE_ERROR_COULDNOTLOADMODULE    6
#define SSCORE_ERROR_INTERNALERROR       255

// ----------------- DLL Function Declarations -----------------------

SSCOREDECLSPEC int SSCORECALL SSCore_GetInfo(SSCoreVersionInfo_p pVersionInfo);

SSCOREDECLSPEC int SSCORECALL SSCore_Initialize(HAB habCaller, char *pchHomeDirectory);
SSCOREDECLSPEC int SSCORECALL SSCore_Uninitialize(void);

SSCOREDECLSPEC int SSCORECALL SSCore_GetListOfModules(SSCoreModuleList_p *ppModuleList);
SSCOREDECLSPEC int SSCORECALL SSCore_FreeListOfModules(SSCoreModuleList_p pModuleList);

SSCOREDECLSPEC int SSCORECALL SSCore_GetCurrentSettings(SSCoreSettings_p pCurrentSettings);
SSCOREDECLSPEC int SSCORECALL SSCore_EncryptPassword(char *pchPassword);
SSCOREDECLSPEC int SSCORECALL SSCore_SetCurrentSettings(SSCoreSettings_p pNewSettings);

SSCOREDECLSPEC int SSCORECALL SSCore_StartSavingNow(void);
SSCOREDECLSPEC int SSCORECALL SSCore_StartModulePreview(char *pchModuleFileName, HWND hwndParent);
SSCOREDECLSPEC int SSCORECALL SSCore_StopModulePreview(HWND hwndParent);

SSCOREDECLSPEC int SSCORECALL SSCore_ConfigureModule(char *pchModuleFileName, HWND hwndOwner);

SSCOREDECLSPEC int SSCORECALL SSCore_TempDisable(void);
SSCOREDECLSPEC int SSCORECALL SSCore_TempEnable(void);

#endif
