/*
 * Screen Saver - Lockup Desktop replacement for OS/2 and eComStation systems
 * Copyright (C) 2004 Doodle
 *
 * Contact: doodle@dont.spam.me.scenergy.dfmk.hu
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 */

#ifndef __SSMODULE_H__
#define __SSMODULE_H__

#define SSMODULECALL __syscall
#define SSMODULEDECLSPEC __declspec(dllexport)

// ----------------- Type and error definitions -----------------------

#define SSMODULE_MAXNAMELEN  1024
#define SSMODULE_MAXDESCLEN  4096
typedef struct SSModuleDesc_s
{
  int iVersionMajor;
  int iVersionMinor;

  char achModuleName[SSMODULE_MAXNAMELEN];
  char achModuleDesc[SSMODULE_MAXDESCLEN];

  int bConfigurable;
  int bSupportsPasswordProtection;
} SSModuleDesc_t, *SSModuleDesc_p;

#define SSMODULE_NOERROR                     0
#define SSMODULE_ERROR_INVALIDPARAMETER      1
#define SSMODULE_ERROR_NOTINITIALIZED        2
#define SSMODULE_ERROR_ALREADYINITIALIZED    3
#define SSMODULE_ERROR_NOTSUPPORTED          4
#define SSMODULE_ERROR_NOTRUNNING            5
#define SSMODULE_ERROR_ALREADYRUNNING        6
#define SSMODULE_ERROR_USERPRESSEDCANCEL     7
#define SSMODULE_ERROR_INTERNALERROR       255

// ----------------- DLL Function Declarations -----------------------

SSMODULEDECLSPEC int SSMODULECALL SSModule_GetModuleDesc(SSModuleDesc_p pModuleDesc);

SSMODULEDECLSPEC int SSMODULECALL SSModule_Configure(HWND hwndOwner, char *pchHomeDirectory);

SSMODULEDECLSPEC int SSMODULECALL SSModule_StartSaving(HWND hwndParent, char *pchHomeDirectory, int bPreviewMode);
SSMODULEDECLSPEC int SSMODULECALL SSModule_StopSaving(void);

SSMODULEDECLSPEC int SSMODULECALL SSModule_AskUserForPassword(int iPwdBuffSize, char *pchPwdBuff);
SSMODULEDECLSPEC int SSMODULECALL SSModule_ShowWrongPasswordNotification(void);


// All these again as function pointer types

typedef int SSMODULECALL (*pfn_SSModule_GetModuleDesc)(SSModuleDesc_p pModuleDesc);

typedef int SSMODULECALL (*pfn_SSModule_Configure)(HWND hwndOwner, char *pchHomeDirectory);

typedef int SSMODULECALL (*pfn_SSModule_StartSaving)(HWND hwndParent, char *pchHomeDirectory, int bPreviewMode);
typedef int SSMODULECALL (*pfn_SSModule_StopSaving)(void);

typedef int SSMODULECALL (*pfn_SSModule_AskUserForPassword)(int iPwdBuffSize, char *pchPwdBuff);
typedef int SSMODULECALL (*pfn_SSModule_ShowWrongPasswordNotification)(void);

#endif
